// src/layouts/Navbar/Navbar.js
import React from 'react';
import { Link, useNavigate } from 'react-router-dom';
import '../../styles/main.css';
import { logout } from '../../services/auth';

const Navbar = () => {
    const navigate = useNavigate();
    const isAuthenticated = !!localStorage.getItem('isAuthenticated');
    const isAdmin = !!localStorage.getItem('isAdmin');

    const handleLogout = async () => {
        await logout();
        navigate('/');
        window.location.reload(); // Refresh to update Navbar
    };

    return (
        <nav className="navbar navbar-expand-lg navbar-light bg-light">
            <div className="container">
                <Link className="navbar-brand" to="/">MisplaceAI</Link>
                <button className="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
                    aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                    <span className="navbar-toggler-icon"></span>
                </button>
                <div className="collapse navbar-collapse" id="navbarNav">
                    <ul className="navbar-nav ml-auto">
                        <li className="nav-item">
                            <Link className="nav-link" to="/">Home</Link>
                        </li>
                        {isAuthenticated && !isAdmin && (
                            <>
                                <li className="nav-item">
                                    <Link className="nav-link" to="/detection-options">Detect Misplaced Items</Link>
                                </li>
                                <li className="nav-item">
                                    <Link className="nav-link" to="/user/dashboard">User Dashboard</Link>
                                </li>
                            </>
                        )}
                        {!isAuthenticated && (
                            <>
                                <li className="nav-item">
                                    <Link className="nav-link" to="/login">Login</Link>
                                </li>
                                <li className="nav-item">
                                    <Link className="nav-link" to="/register">Register</Link>
                                </li>
                            </>
                        )}
                        {isAuthenticated && (
                            <li className="nav-item">
                                <button className="nav-link btn btn-link" onClick={handleLogout}>Logout</button>
                            </li>
                        )}
                        {isAdmin && (
                            <>
                                <li className="nav-item">
                                    <Link className="nav-link" to="/admin/dashboard">Admin Dashboard</Link>
                                </li>
                            </>
                        )}
                    </ul>
                </div>
            </div>
        </nav>
    );
};

export default Navbar;
